@@ -303,7 +303,7 @@ _hildon_file_system_get_special_location(GtkFileSystem *fs,
         g_free(data.uri);
     }
 
-    if (data.result && data.is_child)
+    if (data.result)
       hildon_file_system_special_location_volumes_changed (data.result, fs);
 
     return data.result;
@@ -499,8 +499,8 @@ hex_digit_to_int (char d)
   return -1;
 }
 
-static char *
-unescape_string (const char *escaped)
+char *
+hildon_file_system_unescape_string (const char *escaped)
 {
   char *result = g_strdup (escaped);
   char *a, *b;
@@ -559,7 +559,7 @@ _hildon_file_system_create_file_name (GtkFileSystem *fs,
     name = g_strdup (gtk_file_info_get_display_name (info));
 
   if (name == NULL)
-    name = unescape_string (get_custom_root_name (path));
+    name = hildon_file_system_unescape_string (get_custom_root_name (path));
 
   return translate_special_name (name);
 }
@@ -600,13 +600,14 @@ _hildon_file_system_create_display_name(GtkFileSystem *fs,
        to gtk_file_info_get_is_folder, but have a mime-type of
        x-directory/normal.
 
-       This is a VERY gross hack and I appologize formally.  My only
+       This is a VERY gross hack and I apologize formally.  My only
        defense is that I don't want to mess with the
        GtkFileSystemMemory itself at this point.  I only feel
        comfortable changing what is displayed and not what the
        filesystem tells is stored in it.
     */
-    if (!is_folder && strcmp (mime_type, "x-directory/normal") == 0)
+    if (!is_folder && mime_type &&
+        strcmp (mime_type, "x-directory/normal") == 0)
       only_known = FALSE;
 
     dot = _hildon_file_system_search_extension (str, only_known, is_folder);
